@@ -1,5 +1,6 @@
 import argparse
 
+from . import notes
 from . import tarball
 from . import version
 
@@ -14,5 +15,8 @@ if __name__ == "__main__":
     tarball_parser.add_argument("--target", required=True)
     tarball_parser.set_defaults(func=tarball.main)
 
+    notes_parser = arg_subparsers.add_parser("notes")
+    notes_parser.set_defaults(func=notes.main)
+
     args = arg_parser.parse_args()
     args.func(args)
